@@ -49,7 +49,7 @@ class BuildExt(build_ext):
     def initialize_options(self):
         build_ext.initialize_options(self)
         pyversion = sys.version[0:3][0] + sys.version[0:3][2] #returns something like 32
-        libsearch = ['/usr/lib', '/usr/lib/' + platform.machine() + '-' + platform.system().lower() + '-gnu', '/usr/local/lib']
+        libsearch = ['/usr/lib', '/usr/lib64', '/usr/lib/' + platform.machine() + '-' + platform.system().lower() + '-gnu', '/usr/local/lib', '/usr/local/lib64']
         includesearch = ['/usr/include', '/usr/local/include']
         if 'VIRTUAL_ENV' in os.environ and os.path.exists(os.environ['VIRTUAL_ENV'] + '/lib'):
             libsearch.insert(0, os.environ['VIRTUAL_ENV'] + '/lib')
@@ -97,7 +97,6 @@ class BuildExt(build_ext):
         self.boostlib = "boost_python"
         if os.path.exists('/usr/local/opt/boost-python3'):
             #Mac OS X with homebrew
-            self.boostlib = "boost_python3"
             libsearch.insert(0,'/usr/local/opt/boost-python3/lib')
             libsearch.insert(0,'/usr/local/opt/boost/lib')
             includesearch.insert(0,'/usr/local/opt/boost/include')
@@ -116,6 +115,10 @@ class BuildExt(build_ext):
                 self.boost_library_dir = d
                 self.boostlib = "boost_python"
                 break
+            elif os.path.exists(d + "/libboost_python" + pyversion + ".dylib"): #Mac OS X
+                self.boost_library_dir = d
+                self.boostlib = "boost_python" + pyversion
+                break
             elif os.path.exists(d + "/libboost_python3.dylib"): #Mac OS X
                 self.boost_library_dir = d
                 self.boostlib = "boost_python3"
@@ -191,7 +194,7 @@ timblModule = Extension("timblapi", ["src/timblapi.cc"],
 
 setup(
     name="python3-timbl",
-    version="2018.03.07",
+    version="2019.12.09",
     description="Python 3 language binding for the Tilburg Memory-Based Learner",
     author="Sander Canisius, Maarten van Gompel",
     author_email="S.V.M.Canisius@uvt.nl, proycon@anaproy.nl",
